@@ -556,9 +556,10 @@ async def train_model(
     wait_time: int = 1,
 ) -> Tuple[Dict[Text, Any], Dict[Text, Any]]:
     console.print(
-        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Queuing training job for: "
-        f"Project ID: {project_id}; Language: {language}; "
-        f"[deep_sky_blue2]INFO[/deep_sky_blue2] Model Name: {model_name}"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Queuing training job for: \n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Project ID: {project_id}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Language: {language}\n"
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Model Name: {model_name}"
     )
     payload = {PROJECT_ID: project_id, LANGUAGE: language, MODEL_NAME: model_name}
     HEADERS = copy(COMMON_HEADERS)
@@ -646,22 +647,22 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     table.add_column("Intent Confidence")
     table.add_column("Response Time (sec)")
     table.add_row(
-        nlu_response[DATA]["text"][:30] + "[...]",
+        nlu_response[DATA]["text"],
         nlu_response[DATA]["intent"]["name"],
-        nlu_response[DATA]["intent"]["confidence"],
+        str(nlu_response[DATA]["intent"]["confidence"]),
         str(response_time / 1000),
     )
     console.print(table)
     intent_ranking_table = Table(
         show_header=True, header_style="bold #c47900", show_lines=True
     )
-    table.add_column("Intent")
-    table.add_column("Confidence")
+    intent_ranking_table.add_column("Intent")
+    intent_ranking_table.add_column("Confidence")
 
     for row in nlu_response[DATA]["intent_ranking"]:
         intent_ranking_table.add_row(
             row["name"],
-            row["confidence"],
+            str(row["confidence"]),
         )
     console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] Intent Ranking")
     console.print(intent_ranking_table)
@@ -669,6 +670,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     for e in nlu_response["data"]["entities"]:
         e[START_INDEX] = e["start"]
         e[END_INDEX] = e["end"]
+        e[TYPE] = e["entity"]
         formatted_entities.append(e)
     print_ner_response(formatted_entities, nlu_response["data"]["text"])
 
